@@ -18,7 +18,7 @@
 // | Author: Dan Allen <dan@mojavelinux.com>
 // +----------------------------------------------------------------------+
 
-// $Id: Command.php 234202 2007-04-20 21:08:48Z cconstantine $
+// $Id$
 
 // }}}
 // {{{ includes
@@ -55,7 +55,7 @@ define('SYSTEM_COMMAND_NONZERO_EXIT',     -12);
  *
  * @author  Anders Johannsen <anders@johannsen.com>
  * @author  Dan Allen <dan@mojavelinux.com>
- * @version $Revision: 234202 $
+ * @version $Revision$
  */
 
 // }}}
@@ -148,7 +148,8 @@ class System_Command {
             'OUTPUT'     => true,
             'NOHUP'      => false,
             'BACKGROUND' => false,
-            'STDERR'     => false
+            'STDERR'     => false,
+            'AUTORESET'  => false
         );
 
         // prepare the available control operators
@@ -223,6 +224,9 @@ class System_Command {
      *              method of the Pear_ERROR object returned by
      *              execute().;
      *
+     * 'AUTORESET'  Automatically call reset() after a successful
+     *              call of execute();
+     *
      * @param string $in_option is a case-sensitive string,
      *                          corresponding to the option
      *                          that should be changed
@@ -408,6 +412,9 @@ class System_Command {
             $line = "system(\"{$this->systemCommand}$suffix\");";
             $function = create_function('', $line);
             register_shutdown_function($function);
+            if ($this->options['AUTORESET']) {
+                $this->reset();
+            }
             return true;
         } 
         else {
@@ -438,6 +445,10 @@ class System_Command {
                 }
             }
 
+            if ((!PEAR::isError($return)) && ($this->options['AUTORESET'])) {
+                $this->reset();
+            }
+
             unlink($tmpFile);
             return $return;
         }
